/*
 * 쐬: 2003/12/06
 *
 */
package com.muimi.cs;

import java.util.HashSet;
import java.util.Set;

import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.debug.internal.ui.views.console.ConsoleDocument;
import org.eclipse.debug.internal.ui.views.console.ConsoleView;
import org.eclipse.debug.internal.ui.views.console.ConsoleViewer;
import org.eclipse.debug.ui.console.ConsoleColorProvider;
import org.eclipse.debug.ui.console.IConsoleColorProvider;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.plugin.AbstractUIPlugin;


/**
 * @author miya
 *
 */
public class CSPlugin extends AbstractUIPlugin {

	private static CSPlugin plugin;

	private Set items = new HashSet();
	private String lastItem = null;
	


	public CSPlugin(IPluginDescriptor descriptor) {
		super(descriptor);
		plugin = this;

		//default candidate items
		items.add("org/apache/log4j/Logger.class");
		items.add("org/jnp/interfaces/NamingContextFactory.class");
		items.add("weblogic/jndi/WLInitialContextFactory.class");
		items.add("com/mysql/jdbc/Driver.class");
		items.add("oracle/jdbc/driver/OracleDriver.class");
		items.add("org/w3c/dom/Document.class");
		items.add("com/muimi/cs/CSPlugin.class");
		items.add("org/eclipse/jface/action/IAction.class");
		items.add("org/eclipse/ant/core/AntCorePlugin.class");
		items.add("org/apache/xerces/dom/DocumentImpl.class");
	}

	public static CSPlugin getDefault() {
		return plugin;
	}
	
	



	public static void openSearchDialog(ClassLoader loader){
		getDefault().openSearchDialogInternal(loader);
	}


	private void openSearchDialogInternal(ClassLoader loader){

		ComboInputDialog dialog = new ComboInputDialog(
			null, 
			"Search Resource From Classpath", 
			"Input resource path. " 
			+ "if you specified class file , package is separated by not '.' but '/' and add file extenstion '.class'" 
			+ "\n(ex. org/apache/log4j/Logger.class)",
			(String[])items.toArray(new String[0]),
			lastItem, 
			null
		);

		int code = dialog.open();
		if(code == InputDialog.OK){
			String item = dialog.getValue();
			lastItem = item;
			items.add(item);
			dispResource(loader, item);
		}
		
	}


	public static void dispResource(ClassLoader loader, String path) {

		String s  
			= "---------------------------" + "\n"
			+ "Search Resource Result" + "\n"
			+ "---------------------------" + "\n"
			+ "Target resource : " + path
			+ "\n"
			+ "[Search from SpecifiedLoader(maybe Plugin)]" + "\n"
			+ listLoader(loader, path)
			+ "\n"
			+ "[Search from Current Thread(maybe System) ClassLoader]" + "\n"
			+ listLoader(Thread.currentThread().getContextClassLoader(), path)
			+ "\n"
//			+ "---Search from System ClassLoader---" + "\n"
//			+ listLoader(ClassLoader.getSystemClassLoader(), path)
//			+ "\n"
			;

		CSPlugin.logToConsole(s);
	}

	private static String listLoader(ClassLoader loader, String path) {
		StringBuffer sb = new StringBuffer();
		sb.append(loader.getClass() + "\n");
		sb.append("  " + loader.getResource(path) + "\n");

		loader = loader.getParent();
		if (loader != null) {
			sb.append(listLoader(loader, path) + "\n");
		}
		return sb.toString();
	}

	public static void logToConsole(String message) {
		//݂ConsoleDocument̂Ƃďo͂ĂB
		//Ƃ@Ȃ́H

		try {
			ConsoleView view =
				(ConsoleView) PlatformUI
					.getWorkbench()
					.getActiveWorkbenchWindow()
					.getActivePage()
					.showView("org.eclipse.debug.ui.ConsoleView");

			ConsoleViewer viewer = view.getConsoleViewer();
			IConsoleColorProvider provider = new ConsoleColorProvider();
			ConsoleDocument document = new ConsoleDocument(provider);
			document.set(message);
			viewer.setDocument(document);

		} catch (PartInitException e) {
			log("unexpected error", e);
			//e.printStackTrace();
		}
	}

	public static void log(String message, Throwable t) {
		getDefault().getLog().log(
			new Status(
				IStatus.ERROR,
				getDefault().getDescriptor().getUniqueIdentifier(),
				0,
				message,
				t));
	}

}
